#!/usr/bin/env python
# -*- coding: UTF-8 -*-

import psutil
import os
import sys
import ftplib
import ConfigParser
import string
import datetime
import csv
from subprocess import PIPE, Popen
from datetime import timedelta

monfichier = 'monitoring.html'     #Fichier html des donnees
path= '/home/pi/psutil/' #Modifier le chemin suivant votre installation 

#convertion des unites en Ko,Go,To

def bytes2human(n):
    # http://code.activestate.com/recipes/578019
    # >>> bytes2human(10000)
    # '9.8K'
    # >>> bytes2human(100001221)
    # '95.4M'
    symbols = ('Ko', 'Mo', 'Go', 'To', 'Po', 'Eo', 'Zo', 'Yo')
    prefix = {}
    for i, s in enumerate(symbols):
        prefix[s] = 1 << (i+1)*10
    for s in reversed(symbols):
        if n >= prefix[s]:
            value = float(n) / prefix[s]
            return '%.1f%s' % (value, s)
    return "%sB" % n

# Lecture de la temperature

def get_cpu_temperature():
    process = Popen(['vcgencmd', 'measure_temp'], stdout=PIPE)
    output, _error = process.communicate()
    return float(output[output.index('=') + 1:output.rindex("'")])


# Temps de dmarrage du raspberry

with open('/proc/uptime', 'r') as f:
    uptime_seconds = round(float(f.readline().split()[0]),0)
    demarrage = str(timedelta(seconds = uptime_seconds))
demarrage = demarrage.replace('days','Jours',1)
demarrage = demarrage.replace(',',' et',1)
demarrage = demarrage.replace('day','Jour',1)
demarrage = demarrage.replace(':','h ',1)
demarrage = demarrage.replace(':','mn ',1)
demarrage = demarrage+ 's '

#ouverture du fichier html


f = open(path + monfichier, 'w')

#Lecture des variables

# SD card

valeur = psutil.disk_usage('/')
part = psutil.disk_partitions(all=False)
infopart = (part[0])[2]        # extration de l'extension
total = bytes2human(valeur.total)
utilise = bytes2human(valeur.used)
libre = bytes2human(valeur.free)
pourcent = str(valeur.percent)

#CPU

usagecpu = str(psutil.cpu_percent(interval=1))
p = psutil.Process(os.getpid())

# Heure mise a jour
dateheure = datetime.datetime.fromtimestamp(p.create_time).strftime("%d-%m-%Y %H:%M")

#Temperature
cpu_temperature = get_cpu_temperature()

p = psutil.Process(os.getpid())
#test = datetime.datetime.fromtimestamp(p.create_time).strftime("%d-%m-%Y %H:%M")

#Memoire Vive RAM
valeur = psutil.virtual_memory()
mtotal = bytes2human(valeur.total)
mdispo = bytes2human(valeur.available)
mutilise = bytes2human(valeur.used)
mlibre = bytes2human(valeur.free) 
mpourcent = str(valeur.percent)

#Memoire SWAP
valeur = psutil.swap_memory()
mstotal = bytes2human(valeur.total)
msutilise = bytes2human(valeur.used)
mslibre = bytes2human(valeur.free) 
mspourcent = str(valeur.percent)

# Type de paragraphe

typepolice1 = """<span style="color:#00008B; font-size: 12pt">"""

# Entete fichier HTML

entete = """
<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN">
<html>
<head>
<title>Etat du syst&egrave;me</title>
</head>
"""

# Corps fichier HTML

corps = """
<body>
<b>Mise &agrave; jour de l'&eacute;tat Raspberry PI: """ + dateheure + """
<br>
""" + typepolice1 + """Etat de la m&eacute;moire SD:</span><br> Total= """ + total + """ Utilis&eacute;e= """+ utilise + """ Libre= """ + libre + """ Pourcentage d'utilisation= """ + pourcent + """% Type= """ + infopart + """
<br>
""" + typepolice1 + """Etat de la CPU:</span><br> Charge de la CPU= """ + usagecpu + """% Temp&eacute;rature de la CPU= """ +  str(cpu_temperature) + """ &deg;C
<br>
""" + typepolice1 + """Etat de la m&eacute;moire vive RAM:</span><br> Total= """ + mtotal + """ Disponible= """ + mdispo + """ Utilis&eacute;e= """+ mutilise + """ Libre= """ + mlibre + """ Pourcentage d'utilisation= """ + mpourcent + """%
<br>
""" + typepolice1 + """Etat de la m&eacute;moire SWAP:</span><br> Total= """ + mstotal + """ Utilis&eacute;e= """+ msutilise + """ Libre= """ + mslibre + """ Pourcentage d'utilisation= """ + mspourcent + """%
<br>
""" + typepolice1 + """Temps de fonctionnement:</span><br> """ + demarrage + """
</boby></html>"""

f.write(entete + corps)
f.close()

print(valeur)

# Lecture du fichier config.ini
config = ConfigParser.ConfigParser()
config.read("/home/pi/psutil/config.ini")
site = config.get("ftp", "site")
user = config.get("ftp", "user")
password = config.get("ftp", "password")
directory = config.get("ftp", "directory")

# Transfert vers le serveur ftp 

session = ftplib.FTP(site,user,password) 
myfile = open(path + monfichier,'rb')                        
session.storbinary("STOR " + directory + monfichier, myfile,1024)           
myfile.close()                                         
session.quit()  

#Enregistrement des valeurs CPU

class PasswdDialect(csv.Dialect):     #Config du fichier CSV
    # Separateur de champ
    delimiter = ";"
    # Separateur de ''chaine''
    quotechar = None
    # Gestion du separateur dans les ''chaines''
    escapechar = None
    doublequote = None
    # Fin de ligne
    lineterminator = "\r\n"
    # Ajout automatique du separateur de chaine (pour ''writer'')
    quoting = csv.QUOTE_NONE
    # Ne pas ignorer les espaces entre le delimiteur de chaine
    # et le texte
    skipinitialspace = False

nbval = 30 # nbrs d'enregistrements
fmon = path + "cpu.txt" # Fichier d enregistrement des valeurs
try:
    file = open(fmon,"r")
    a = []
    reader = csv.reader(file,PasswdDialect())
    row = reader.next()
    for i in range(1,nbval):
        row = reader.next()
        a.append(row[1])
    file.close()
    file = open(fmon,"wb")
    writer = csv.writer(file,PasswdDialect())
    writer.writerow(('ligne','cpu'))
    writer.writerow(('1',usagecpu))
    for i in range(2,nbval):
        writer.writerow((i,a[(i-2)]))
    file.close()
    print a

except:
    file = open(fmon,"wb")
    a = []
    writer = csv.writer(file,PasswdDialect())
    writer.writerow(('ligne','cpu'))
    for i in range(1,nbval):
        writer.writerow((i,i))
        a.append((i*10))
    file.close()

